@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2010 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -53,6 +53,7 @@ guint         gva_main_statusbar_push            (guint context_id,
 void          gva_main_statusbar_pop             (guint context_id);
 void          gva_main_statusbar_remove          (guint context_id,
                                                   guint message_id);
+void          gva_main_clear_search              (void);
 void          gva_main_execute_search            (void);
 gchar *       gva_main_get_last_search_text      (void);
 void          gva_main_set_last_search_text      (const gchar *text);
@@ -64,6 +65,11 @@ void          gva_main_set_last_selected_match   (const gchar *column_name,
 /* Signal Handlers */
 
 void          gva_main_search_entry_activate_cb  (GtkEntry *entry);
+void          gva_main_search_entry_changed_cb   (GtkEntry *entry);
+void          gva_main_search_entry_icon_release_cb
+                                                 (GtkEntry *entry,
+                                                  GtkEntryIconPosition position,
+                                                  GdkEvent *event);
 void          gva_main_search_entry_notify_cb    (GtkEntry *entry,
                                                   GParamSpec *pspec);
 gboolean      gva_main_search_query_tooltip_cb   (GtkWidget *widget,
