@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2010 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -26,6 +26,7 @@
 #include "gva-game-store.h"
 #include "gva-main.h"
 #include "gva-mame.h"
+#include "gva-music-button.h"
 #include "gva-mute-button.h"
 #include "gva-play-back.h"
 #include "gva-preferences.h"
@@ -41,6 +42,9 @@
 #define SQL_INSERT_LASTPLAYED \
         "INSERT INTO lastplayed VALUES ('%s', %" G_GINT64_FORMAT ")"
 
+#define WEBSITE_URL \
+        "http://mbarnes.github.com/gnome-video-arcade"
+
 static GtkBuilder *builder = NULL;
 static GtkUIManager *manager = NULL;
 static GtkActionGroup *action_group = NULL;
@@ -53,7 +57,7 @@ static const gchar *authors[] =
         NULL
 };
 static const gchar *copyright =
-"Copyright \xC2\xA9 2007-2009 Matthew Barnes";
+"Copyright \xC2\xA9 2007-2010 Matthew Barnes";
 static const gchar *license =
 "GNOME Video Arcade is free software; you can redistribute it "
 "and/or modify it under the terms of the GNU General Public License "
@@ -146,6 +150,8 @@ action_about_cb (GtkAction *action)
                 "copyright", copyright,
                 "license", license,
                 "wrap-license", TRUE,
+                "website", WEBSITE_URL,
+                "website-label", _("Visit the Website"),
                 "authors", authors,
                 "translator-credits", _("translator-credits"),
                 "logo", logo,
@@ -170,6 +176,14 @@ action_add_column_cb (GtkAction *action,
         gtk_tree_view_column_set_visible (column, TRUE);
 }
 
+/**
+ * GVA_ACTION_AUTO_PLAY:
+ *
+ * This toggle action tracks the user's preference for whether to
+ * automatically start playing a music clip from the selected game
+ * (if available) when the Properties window is open.
+ **/
+
 /**
  * GVA_ACTION_AUTO_SAVE:
  *
@@ -281,6 +295,7 @@ action_next_game_cb (GtkAction *action)
 static void
 action_play_back_cb (GtkAction *action)
 {
+        GtkWidget *widget;
         GvaProcess *process;
         GtkTreeModel *model;
         GtkTreeView *view;
@@ -309,6 +324,9 @@ action_play_back_cb (GtkAction *action)
         inpname = g_strdelimit (g_path_get_basename (inpfile), ".", '\0');
         g_free (inpfile);
 
+        widget = GVA_WIDGET_PROPERTIES_MUSIC_BUTTON;
+        gva_music_button_pause (GVA_MUSIC_BUTTON (widget));
+
         process = gva_mame_playback_game (name, inpname, &error);
         gva_error_handle (&error);
 
@@ -429,6 +447,7 @@ action_quit_cb (GtkAction *action)
 static void
 action_record_cb (GtkAction *action)
 {
+        GtkWidget *widget;
         GvaProcess *process;
         const gchar *name;
         gchar *inpname;
@@ -439,6 +458,9 @@ action_record_cb (GtkAction *action)
 
         inpname = gva_choose_inpname (name);
 
+        widget = GVA_WIDGET_PROPERTIES_MUSIC_BUTTON;
+        gva_music_button_pause (GVA_MUSIC_BUTTON (widget));
+
         process = gva_mame_record_game (name, inpname, &error);
         gva_error_handle (&error);
 
@@ -604,6 +626,7 @@ action_show_play_back_cb (GtkAction *action)
 static void
 action_start_cb (GtkAction *action)
 {
+        GtkWidget *widget;
         GvaProcess *process;
         const gchar *name;
         GError *error = NULL;
@@ -614,6 +637,9 @@ action_start_cb (GtkAction *action)
         if (!gva_preferences_get_auto_save ())
                 gva_mame_delete_save_state (name);
 
+        widget = GVA_WIDGET_PROPERTIES_MUSIC_BUTTON;
+        gva_music_button_pause (GVA_MUSIC_BUTTON (widget));
+
         process = gva_mame_run_game (name, &error);
         gva_error_handle (&error);
 
@@ -828,6 +854,14 @@ static GtkActionEntry entries[] =
 
 static GtkToggleActionEntry toggle_entries[] =
 {
+        { "auto-play",
+          NULL,
+          N_("Play music _automatically"),
+          NULL,
+          N_("Automatically play a music clip from the selected game"),
+          NULL,     /* GConfBridge monitors the state */
+          FALSE },  /* GConf overrides this */
+
         { "auto-save",
           NULL,
           N_("_Restore previous state when starting a game"),
