@@ -1,4 +1,4 @@
-/* Copyright 2007-2009 Matthew Barnes
+/* Copyright 2007-2010 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -23,10 +23,6 @@
 #include "gva-error.h"
 #include "gva-mame.h"
 
-#ifdef WITH_GNOME
-#include <gnome.h>
-#endif
-
 #define DEFAULT_MONOSPACE_FONT_NAME     "Monospace 10"
 
 #define GCONF_MONOSPACE_FONT_NAME_KEY \
@@ -38,6 +34,18 @@ gchar *opt_inspect;
 gboolean opt_version;
 gboolean opt_which_emulator;
 
+static void
+log_handler (const gchar *log_domain,
+             GLogLevelFlags log_level,
+             const gchar *message,
+             const gchar *log_level_id)
+{
+        if ((gva_get_debug_flags () & log_level) != 0)
+                g_print (
+                        "%s-LOG-DEBUG-%s: %s\n",
+                        log_domain, log_level_id, message);
+}
+
 static gboolean
 inpname_exists (const gchar *inppath, const gchar *inpname)
 {
@@ -165,11 +173,29 @@ gva_get_debug_flags (void)
                 {
                         { "mame",  GVA_DEBUG_MAME },
                         { "sql",   GVA_DEBUG_SQL },
-                        { "io",    GVA_DEBUG_IO }
+                        { "io",    GVA_DEBUG_IO },
+                        { "inp",   GVA_DEBUG_INP },
+                        { "gst",   GVA_DEBUG_GST }
                 };
 
                 const gchar *env = g_getenv ("GVA_DEBUG");
 
+                g_log_set_handler (
+                        G_LOG_DOMAIN, GVA_DEBUG_MAME,
+                        (GLogFunc) log_handler, "MAME");
+                g_log_set_handler (
+                        G_LOG_DOMAIN, GVA_DEBUG_SQL,
+                        (GLogFunc) log_handler, "SQL");
+                g_log_set_handler (
+                        G_LOG_DOMAIN, GVA_DEBUG_IO,
+                        (GLogFunc) log_handler, "IO");
+                g_log_set_handler (
+                        G_LOG_DOMAIN, GVA_DEBUG_INP,
+                        (GLogFunc) log_handler, "INP");
+                g_log_set_handler (
+                        G_LOG_DOMAIN, GVA_DEBUG_GST,
+                        (GLogFunc) log_handler, "GST");
+
                 flags = g_parse_debug_string (
                         (env != NULL) ? env : "", debug_keys,
                         G_N_ELEMENTS (debug_keys));
@@ -282,8 +308,7 @@ gva_get_user_data_dir (void)
         if (G_UNLIKELY (user_data_dir == NULL))
         {
                 user_data_dir = g_build_filename (
-                        g_get_user_data_dir (),
-                        "applications", PACKAGE, NULL);
+                        g_get_user_data_dir (), PACKAGE, NULL);
 
                 if (g_mkdir_with_parents (user_data_dir, 0777) < 0)
                         g_warning (
@@ -308,7 +333,6 @@ void
 gva_help_display (GtkWindow *parent,
                   const gchar *link_id)
 {
-#if GTK_CHECK_VERSION(2,14,0)
         GString *uri;
         GtkWidget *dialog;
         GdkScreen *screen = NULL;
@@ -343,28 +367,6 @@ gva_help_display (GtkWindow *parent,
 
 exit:
         g_string_free (uri, TRUE);
-
-#elif defined WITH_GNOME
-        GtkWidget *dialog;
-        GError *error = NULL;
-
-        if (gnome_help_display ("gnome-video-arcade.xml", link_id, &error))
-                return;
-
-        dialog = gtk_message_dialog_new_with_markup (
-                parent, GTK_DIALOG_DESTROY_WITH_PARENT,
-                GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                "<big><b>%s</b></big>",
-                _(PACKAGE_NAME " could not display the help contents."));
-
-        gtk_message_dialog_format_secondary_text (
-                GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
-
-        gtk_dialog_run (GTK_DIALOG (dialog));
-
-        gtk_widget_destroy (dialog);
-        g_error_free (error);
-#endif
 }
 
 /**
