@@ -1,4 +1,4 @@
-/* Copyright 2007, 2008 Matthew Barnes
+/* Copyright 2007 - 2010 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -24,10 +24,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef WITH_GNOME
-#include <gnome.h>
-#endif
-
 #include "gva-audit.h"
 #include "gva-categories.h"
 #include "gva-db.h"
@@ -35,6 +31,7 @@
 #include "gva-history.h"
 #include "gva-main.h"
 #include "gva-mame.h"
+#include "gva-nplayers.h"
 #include "gva-play-back.h"
 #include "gva-preferences.h"
 #include "gva-properties.h"
@@ -42,9 +39,14 @@
 #include "gva-ui.h"
 #include "gva-util.h"
 
+#ifdef HAVE_DBUS
+#include "gva-dbus.h"
+#endif
+
 #define SQL_COUNT_ROMS \
         "SELECT count(*) FROM game WHERE " \
-        "romset NOTNULL AND romset != 'not found'"
+        "romset NOTNULL AND romset != 'not found' " \
+        "AND isbios != 'yes'"
 
 static GOptionEntry entries[] =
 {
@@ -104,7 +106,6 @@ warn_if_no_roms (void)
                 "<big><b>%s</b></big>",
                 _("No ROM files found"));
 
-#ifdef WITH_GNOME
         gtk_message_dialog_format_secondary_markup (
                 GTK_MESSAGE_DIALOG (dialog),
                 _("GNOME Video Arcade was unable to locate any ROM files. "
@@ -114,14 +115,6 @@ warn_if_no_roms (void)
 
         gtk_dialog_add_button (
                 GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
-#else
-        gtk_message_dialog_format_secondary_markup (
-                GTK_MESSAGE_DIALOG (dialog),
-                _("GNOME Video Arcade was unable to locate any ROM files. "
-                  "It could be that MAME is misconfigured or no ROM files "
-                  "are installed. Consult the user documentation for more "
-                  "details and troubleshooting tips."));
-#endif
 
         if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_HELP)
                 gva_help_display (GTK_WINDOW (dialog), "troubleshooting");
@@ -172,7 +165,7 @@ start (void)
         {
                 gva_error_handle (&error);
                 return;
-        }        
+        }
 
         gtk_action_set_sensitive (GVA_ACTION_SEARCH, TRUE);
         gtk_action_set_sensitive (GVA_ACTION_SHOW_CLONES, TRUE);
@@ -198,10 +191,6 @@ start (void)
 gint
 main (gint argc, gchar **argv)
 {
-#ifdef WITH_GNOME
-        GnomeProgram *program;
-        GOptionContext *context;
-#endif
         gchar *path;
         GError *error = NULL;
 
@@ -211,23 +200,19 @@ main (gint argc, gchar **argv)
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
 
-#ifdef WITH_GNOME
-        context = g_option_context_new (NULL);
-        g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-        g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
-
-        program = gnome_program_init (
-                PACKAGE, VERSION, LIBGNOMEUI_MODULE, argc, argv,
-                GNOME_PROGRAM_STANDARD_PROPERTIES,
-                GNOME_PARAM_GOPTION_CONTEXT, context,
-                GNOME_PARAM_NONE);
-#else
         gtk_init_with_args (
                 &argc, &argv, NULL, entries, GETTEXT_PACKAGE, &error);
         if (error != NULL)
                 g_error ("%s", error->message);
+
+#ifdef HAVE_GSTREAMER
+        if (!gst_init_check (&argc, &argv, &error))
+                g_error ("%s", error->message);
 #endif
 
+        /* This installs handlers for our custom debug log levels. */
+        gva_get_debug_flags ();
+
         /* Change the working directory to that of the MAME executable.
          * Why?  Because SDLMAME's default configuration uses relative
          * search paths such as "rompath = roms".  The paths are relative
@@ -285,13 +270,17 @@ main (gint argc, gchar **argv)
         gva_history_init (&error);
         gva_error_handle (&error);
 
+        gva_nplayers_init (&error);
+        gva_error_handle (&error);
+
+#ifdef HAVE_DBUS
+        gva_dbus_init (&error);
+        gva_error_handle (&error);
+#endif
+
         gtk_init_add ((GtkFunction) start, NULL);
 
         gtk_main ();
 
-#ifdef WITH_GNOME
-        g_object_unref (program);
-#endif
-
         return EXIT_SUCCESS;
 }
